@@ -38,6 +38,13 @@ class DogStatsd(object):
         self.connect(host, port)
         self.encoding = 'utf-8'
 
+    def get_socket(self):
+        '''
+        Return a connected socket
+        '''
+        if not self.socket:
+            self.connect(self._host, self._port)
+        return self.socket
 
     def __enter__(self):
         self.open_buffer(self.max_buffer_size)
